@@ -4,8 +4,8 @@ from datetime import datetime
 from enum import Enum
 from typing import Any, Union
 
+from ._compat import cached_property
 from .backports.enum import StrEnum
-from .backports.functools import cached_property
 from .lock import LockDoorStatus, LockStatus
 from .time import epoch_to_datetime, parse_datetime
 from .users import YaleUser, get_user_info
@@ -24,6 +24,7 @@ ACTION_LOCK_BLE_UNLOCK = "ble_unlock"
 ACTION_LOCK_REMOTE_LOCK = "remote_lock"
 ACTION_LOCK_REMOTE_UNLATCH = "remote_unlatch"
 ACTION_LOCK_REMOTE_UNLOCK = "remote_unlock"
+ACTION_LOCK_PIN_LOCK = "pin_lock"
 ACTION_LOCK_PIN_UNLATCH = "pin_unlatch"
 ACTION_LOCK_PIN_UNLOCK = "pin_unlock"
 ACTION_LOCK_MANUAL_LOCK = "manual_lock"
@@ -40,6 +41,8 @@ ACTION_HOMEKEY_UNLATCH = "homekey_unlatch"
 ACTION_HOMEKEY_UNLOCK = "homekey_unlock"
 ACTION_LINKED_LOCK = "linked_lock"
 ACTION_LINKED_UNLOCK = "linked_unlock"
+ACTION_LOCK_FINGER_LOCK = "finger_lock"
+ACTION_LOCK_FINGER_UNLOCK = "finger_unlock"
 
 ACTION_DOOR_OPEN = "dooropen"
 ACTION_DOOR_OPEN_2 = "door_open"
@@ -95,11 +98,14 @@ ACTIVITY_ACTIONS_LOCK_OPERATION = {
     ACTION_LOCK_REMOTE_LOCK,
     ACTION_LOCK_REMOTE_UNLATCH,
     ACTION_LOCK_REMOTE_UNLOCK,
+    ACTION_LOCK_PIN_LOCK,
     ACTION_LOCK_PIN_UNLATCH,
     ACTION_LOCK_PIN_UNLOCK,
     ACTION_LOCK_MANUAL_LOCK,
     ACTION_LOCK_MANUAL_UNLATCH,
     ACTION_LOCK_MANUAL_UNLOCK,
+    ACTION_LOCK_FINGER_LOCK,
+    ACTION_LOCK_FINGER_UNLOCK,
 }
 
 
@@ -122,6 +128,11 @@ ACTIVITY_TO_FIRST_LAST_NAME = {
     ACTION_LOCK_MANUAL_LOCK: ("Manual", "Lock"),
     ACTION_LOCK_MANUAL_UNLATCH: ("Manual", "Unlatch"),
     ACTION_LOCK_MANUAL_UNLOCK: ("Manual", "Unlock"),
+    ACTION_LOCK_FINGER_LOCK: ("Fingerprint", "Lock"),
+    ACTION_LOCK_FINGER_UNLOCK: ("Fingerprint", "Unlock"),
+    ACTION_LOCK_PIN_LOCK: ("Pin", "Lock"),
+    ACTION_LOCK_PIN_UNLATCH: ("Pin", "Unlatch"),
+    ACTION_LOCK_PIN_UNLOCK: ("Pin", "Unlock"),
 }
 
 
@@ -135,8 +146,11 @@ ACTIVITY_ACTIONS_DOOR_OPERATION = {
 KEYPAD_ACTIONS = {
     ACTION_LOCK_ONETOUCHLOCK,
     ACTION_LOCK_ONETOUCHLOCK_2,
+    ACTION_LOCK_PIN_LOCK,
     ACTION_LOCK_PIN_UNLATCH,
     ACTION_LOCK_PIN_UNLOCK,
+    ACTION_LOCK_FINGER_LOCK,
+    ACTION_LOCK_FINGER_UNLOCK,
 }
 REMOTE_ACTIONS = {
     ACTION_LOCK_REMOTE_LOCK,
@@ -191,11 +205,14 @@ ACTIVITY_ACTION_STATES: dict[str, LockStatus | LockDoorStatus] = {
     ACTION_LOCK_REMOTE_LOCK: LockStatus.LOCKED,
     ACTION_LOCK_REMOTE_UNLATCH: LockStatus.UNLATCHED,
     ACTION_LOCK_REMOTE_UNLOCK: LockStatus.UNLOCKED,
+    ACTION_LOCK_PIN_LOCK: LockStatus.LOCKED,
     ACTION_LOCK_PIN_UNLATCH: LockStatus.UNLATCHED,
     ACTION_LOCK_PIN_UNLOCK: LockStatus.UNLOCKED,
     ACTION_LOCK_MANUAL_LOCK: LockStatus.LOCKED,
     ACTION_LOCK_MANUAL_UNLATCH: LockStatus.UNLATCHED,
     ACTION_LOCK_MANUAL_UNLOCK: LockStatus.UNLOCKED,
+    ACTION_LOCK_FINGER_LOCK: LockStatus.LOCKED,
+    ACTION_LOCK_FINGER_UNLOCK: LockStatus.UNLOCKED,
 }
 
 
@@ -458,17 +475,17 @@ class LockOperationActivity(Activity):
         image_info = calling_user.get("imageInfo") or calling_user
         original = image_info.get("original")
 
-        if type(original) is str:  # pylint: disable=unidiomatic-typecheck # noqa: E721
+        if type(original) is str:  # pylint: disable=unidiomatic-typecheck
             operator_image_url = original
-        elif type(original) is dict:  # pylint: disable=unidiomatic-typecheck # noqa: E721
+        elif type(original) is dict:  # pylint: disable=unidiomatic-typecheck
             operator_image_url = original.get("secure_url")
         else:
             operator_image_url = None
 
         thumbnail = image_info.get("thumbnail")
-        if type(thumbnail) is str:  # pylint: disable=unidiomatic-typecheck # noqa: E721
+        if type(thumbnail) is str:  # pylint: disable=unidiomatic-typecheck
             operator_thumbnail_url = thumbnail
-        elif type(thumbnail) is dict:  # pylint: disable=unidiomatic-typecheck # noqa: E721
+        elif type(thumbnail) is dict:  # pylint: disable=unidiomatic-typecheck
             operator_thumbnail_url = thumbnail.get("secure_url")
         else:
             operator_thumbnail_url = None
