@@ -17,8 +17,8 @@ from aiohttp import (
     ServerDisconnectedError,
 )
 
-from .const import HEADER_ACCESS_TOKEN, HEADER_AUGUST_ACCESS_TOKEN
 from .activity import ActivityTypes
+from .alarm import Alarm, AlarmDevice, ArmState
 from .api_common import (
     API_EXCEPTION_RETRY_TIME,
     API_LOCK_ASYNC_URL,
@@ -36,12 +36,14 @@ from .api_common import (
     _api_headers,
     _convert_lock_result_to_activities,
     _process_activity_json,
+    _process_alarm_devices_json,
+    _process_alarms_json,
     _process_doorbells_json,
     _process_locks_json,
 )
-from .const import DEFAULT_BRAND
+from .const import DEFAULT_BRAND, HEADER_ACCESS_TOKEN, HEADER_AUGUST_ACCESS_TOKEN
 from .doorbell import Doorbell, DoorbellDetail
-from .exceptions import YaleApiError, InvalidAuth
+from .exceptions import InvalidAuth, YaleApiError
 from .lock import (
     Lock,
     LockDetail,
@@ -388,17 +390,46 @@ class ApiAsync(ApiCommon):
             API_STATUS_ASYNC_URL, access_token, lock_id
         )
 
+    async def async_get_alarms(self, access_token: str) -> list[Alarm]:
+        if not self.brand_supports_alarms:
+            return []
+        response = await self._async_dict_to_api(
+            self._build_get_alarms_request(access_token)
+        )
+        return _process_alarms_json(await response.json())
+
+    async def async_get_alarm_devices(
+        self, access_token: str, alarm: Alarm
+    ) -> list[AlarmDevice]:
+        if not self.brand_supports_alarms:
+            return []
+        response = await self._async_dict_to_api(
+            self._build_get_alarm_devices_request(
+                access_token, alarm_id=alarm.device_id
+            )
+        )
+        return _process_alarm_devices_json(await response.json())
+
+    async def async_arm_alarm(
+        self, access_token: str, alarm: Alarm, arm_state: ArmState
+    ):
+        if not self.brand_supports_alarms:
+            return {}
+        response = await self._async_dict_to_api(
+            self._build_call_alarm_state_request(access_token, alarm, arm_state)
+        )
+        return await response.json()
+
     async def async_refresh_access_token(self, access_token: str) -> str:
         """Obtain a new api token."""
         response = await self._async_dict_to_api(
             self._build_refresh_access_token_request(access_token)
         )
         response_headers = response.headers
-        access_token = (
+        return (
             response_headers.get(HEADER_ACCESS_TOKEN)
             or response_headers[HEADER_AUGUST_ACCESS_TOKEN]
         )
-        return access_token
 
     async def async_add_websocket_subscription(
         self, access_token: str
