@@ -4,14 +4,16 @@ from __future__ import annotations
 
 import datetime
 import logging
-from typing import Any
 from functools import cache
+from typing import Any
+
+from ._compat import cached_property
 from .activity import ACTION_TO_CLASS, SOURCE_LOCK_OPERATE, SOURCE_LOG, ActivityTypes
-from .const import BASE_URLS, BRANDING, Brand, BRAND_CONFIG, DEFAULT_BRAND, BrandConfig
+from .alarm import Alarm, AlarmDevice, ArmState
+from .const import BASE_URLS, BRAND_CONFIG, BRANDING, DEFAULT_BRAND, Brand, BrandConfig
 from .doorbell import Doorbell
 from .lock import Lock, LockDoorStatus, determine_door_state, door_state_to_string
 from .time import parse_datetime
-from .backports.functools import cached_property
 
 API_EXCEPTION_RETRY_TIME = 0.1
 API_RETRY_TIME = 2.5
@@ -62,6 +64,10 @@ HYPER_BRIDGE_PARAM = "&connection=persistent"
 API_GET_USER_URL = "/users/me"
 API_WEBSOCKET_SUBSCRIBERS = "/websocket/subscribers"
 API_WEBSOCKET_SUBSCRIBERS_WITH_SUBSCRIBER_ID = "/websocket/subscribers/{subscriber_id}"
+API_GET_ALARMS_URL = "/users/alarms/mine"
+API_GET_ALARM_DEVICES_URL = "/alarms/{alarm_id}/devices"
+API_PUT_ALARM_URL = "/alarms/{alarm_id}/state/{arm_state}"
+
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -159,11 +165,11 @@ def _process_activity_json(json_dict: dict[str, Any]) -> list[ActivityTypes]:
     if "events" in json_dict:
         json_dict = json_dict["events"]
     debug = _LOGGER.isEnabledFor(logging.DEBUG)
-    activities: list[ActivityTypes] = []
-    for activity_json in json_dict:
-        if activity := _activity_from_dict(SOURCE_LOG, activity_json, debug):
-            activities.append(activity)
-    return activities
+    return [
+        activity
+        for activity_json in json_dict
+        if (activity := _activity_from_dict(SOURCE_LOG, activity_json, debug))
+    ]
 
 
 def _process_doorbells_json(json_dict: dict[str, Any]) -> list[Doorbell]:
@@ -174,6 +180,14 @@ def _process_locks_json(json_dict: dict[str, Any]) -> list[Lock]:
     return [Lock(device_id, data) for device_id, data in json_dict.items()]
 
 
+def _process_alarms_json(json_dict: list[dict[str, Any]]) -> list[Alarm]:
+    return [Alarm(data.get("alarmID"), data) for data in json_dict]
+
+
+def _process_alarm_devices_json(json_dict: list[dict[str, Any]]) -> list[AlarmDevice]:
+    return [AlarmDevice(data) for data in json_dict]
+
+
 class ApiCommon:
     """Api dict shared between async and sync."""
 
@@ -188,6 +202,11 @@ class ApiCommon:
         """Return if the brand supports doorbells."""
         return self.brand_config.supports_doorbells
 
+    @cached_property
+    def brand_supports_alarms(self) -> bool:
+        """Return if the brand supports alarms."""
+        return self.brand_config.supports_alarms
+
     def get_brand_url(self, url_str: str) -> str:
         """Get url."""
         return f"{self._base_url}{url_str}"
@@ -261,7 +280,10 @@ class ApiCommon:
         }
 
     def _build_get_houses_request(self, access_token: str) -> dict[str, Any]:
-        return self._build_base_request(access_token)
+        return {
+            **self._build_base_request(access_token),
+            "url": self.get_brand_url(API_GET_HOUSES_URL),
+        }
 
     def _build_get_house_request(self, access_token, house_id):
         return {
@@ -362,3 +384,30 @@ class ApiCommon:
             "url": self.get_brand_url(url_str.format(lock_id=lock_id)),
             "timeout": timeout,
         }
+
+    def _build_get_alarms_request(self, access_token: str) -> dict[str, Any]:
+        return {
+            **self._build_base_request(access_token),
+            "url": self.get_brand_url(API_GET_ALARMS_URL),
+        }
+
+    def _build_get_alarm_devices_request(
+        self, access_token: str, alarm_id: str
+    ) -> dict[str, Any]:
+        return {
+            **self._build_base_request(access_token),
+            "url": self.get_brand_url(
+                API_GET_ALARM_DEVICES_URL.format(alarm_id=alarm_id)
+            ),
+        }
+
+    def _build_call_alarm_state_request(
+        self, access_token: str, alarm: Alarm, arm_state: ArmState
+    ) -> dict[str, Any]:
+        return {
+            **self._build_base_request(access_token=access_token, method="PUT"),
+            "url": self.get_brand_url(
+                API_PUT_ALARM_URL.format(alarm_id=alarm.device_id, arm_state=arm_state)
+            ),
+            "json": {"areaIDs": alarm.areaIDs},
+        }
