@@ -1,5 +1,5 @@
+from ._compat import cached_property
 from .device import DeviceDetail
-from .backports.functools import cached_property
 
 BATTERY_LEVEL_FULL = "Full"
 BATTERY_LEVEL_MEDIUM = "Medium"
